@@ -1,11 +1,11 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md#adding-tests
 
-import os
 import filecmp
 from pathlib import Path
 import pytest
 
-from class_generator.class_generator import TESTS_MANIFESTS_DIR, class_generator
+from class_generator.constants import TESTS_MANIFESTS_DIR
+from class_generator.core.generator import class_generator
 
 
 @pytest.mark.parametrize(
@@ -35,4 +35,4 @@ def test_parse_explain(tmpdir_factory, kind):
         output_dir=output_dir,
     )
     for output_file in output_files:
-        assert filecmp.cmp(output_file, f"{os.path.join(TESTS_MANIFESTS_DIR, kind, Path(output_file).parts[-1])}")
+        assert filecmp.cmp(output_file, str(TESTS_MANIFESTS_DIR / kind / Path(output_file).name))
