@@ -497,6 +497,7 @@ class Resource(ResourceConstants):
         HOSTPATHPROVISIONER_KUBEVIRT_IO: str = "hostpathprovisioner.kubevirt.io"
         IMAGE_OPENSHIFT_IO: str = "image.openshift.io"
         IMAGE_REGISTRY: str = "registry.redhat.io"
+        IMAGEREGISTRY_OPERATOR_OPENSHIFT_IO: str = "imageregistry.operator.openshift.io"
         INSTANCETYPE_KUBEVIRT_IO: str = "instancetype.kubevirt.io"
         INTEGREATLY_ORG: str = "integreatly.org"
         K8S_CNI_CNCF_IO: str = "k8s.cni.cncf.io"
@@ -543,6 +544,7 @@ class Resource(ResourceConstants):
         REMEDIATION_MEDIK8S_IO: str = "remediation.medik8s.io"
         RIPSAW_CLOUDBULLDOZER_IO: str = "ripsaw.cloudbulldozer.io"
         ROUTE_OPENSHIFT_IO: str = "route.openshift.io"
+        SAMPLES_OPERATOR_OPENSHIFT_IO: str = "samples.operator.openshift.io"
         SCHEDULING_K8S_IO: str = "scheduling.k8s.io"
         SECURITY_ISTIO_IO: str = "security.istio.io"
         SECURITY_OPENSHIFT_IO: str = "security.openshift.io"
